@@ -12,6 +12,8 @@ import aws_cdk.aws_applicationautoscaling._jsii
 import aws_cdk.aws_cloudwatch._jsii
 import aws_cdk.aws_codeguruprofiler._jsii
 import aws_cdk.aws_ec2._jsii
+import aws_cdk.aws_ecr._jsii
+import aws_cdk.aws_ecr_assets._jsii
 import aws_cdk.aws_efs._jsii
 import aws_cdk.aws_events._jsii
 import aws_cdk.aws_iam._jsii
@@ -24,7 +26,7 @@ import aws_cdk.cx_api._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-cdk/aws-lambda", "1.74.0", __name__[0:-6], "aws-lambda@1.74.0.jsii.tgz"
+    "@aws-cdk/aws-lambda", "1.76.0", __name__[0:-6], "aws-lambda@1.76.0.jsii.tgz"
 )
 
 __all__ = [
